/*
NOME: 0020_DENSTPO_USR_CUSTOSPROD.SQL

DESCRIO: Procedimento para exportao da posio de estoque.

CRIAO: 29/08/2008 - Fabrcio Marcelo da Silva

@C:\Web_503\Xdb\Src\Cli\DEN\Sql\0020_DENSTPO_USR_CUSTOSPROD.SQL

RAISE_APPLICATION_ERROR(-20501, '' , TRUE);
*/

CREATE OR REPLACE PROCEDURE USR_CUSTOSPROD(
     P_DTINVENT IN LANCTOESTOQ.DTLANCESTQ%TYPE)
AS
   V_DTGRV         DATE;
   V_HRGRV         VARCHAR2(04);

   V_FILIAL        VARCHAR2(10);
   V_NOVOCODIGO    INTEGER;
   V_NUMI          INTEGER;
BEGIN
   V_DTGRV := NULL;
   V_HRGRV := NULL;

   /* Retorna data e hora de exportao */
   BEGIN
      SELECT TO_DATE(SYSDATE), TO_CHAR(SYSDATE,'HH24MI')
      INTO V_DTGRV, V_HRGRV
      FROM DUAL;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_DTGRV := NULL;
         V_HRGRV := NULL;
   END;

   DELETE FROM USR_ZWI;

   /* Verificao dos lanamentos de estoque referente a posio de estoque */
   FOR C_MOVESTO IN (SELECT B.CDFILIAL, A.CDARVPROD, B.DTPOSIESTQ,
                            CUSTO_PRODUTO(B.CDFILIAL, B.CDPRODUTO, 3, B.DTPOSIESTQ -1, B.DTPOSIESTQ -1) AS VRESTOQDIA
                       FROM POSESTDIA B, PRODUTO A, 
                            (SELECT DISTINCT(CDFILIAL)
                               FROM FILGRUPFILI
                              WHERE USR_IDPROTHEUS = 'S') F
                      WHERE B.CDFILIAL = F.CDFILIAL
                        AND B.DTPOSIESTQ BETWEEN (TRUNC(P_DTINVENT, 'MM') + 1) AND (P_DTINVENT + 1)
                        AND B.CDPRODUTO = A.CDPRODUTO
                      ORDER BY B.CDFILIAL, A.CDARVPROD, B.DTPOSIESTQ)
   LOOP
      V_FILIAL := NULL;

      SELECT MAX(CDGRUPFILI)
        INTO V_FILIAL
        FROM FILGRUPFILI
       WHERE CDFILIAL = C_MOVESTO.CDFILIAL
         AND USR_IDPROTHEUS = 'S';

      IF NOT V_FILIAL IS NULL THEN

         /* Verifica a existencia */
         SELECT NVL(MAX(WI_IDCUSTO),0)
           INTO V_NUMI
           FROM USR_ZWI
          WHERE WI_EMPRESA = SUBSTR(V_FILIAL,7,2)
            AND WI_FILIAL = SUBSTR(V_FILIAL,9,2)
            AND WI_COD = SUBSTR(C_MOVESTO.CDARVPROD,1,15)
            AND WI_DATA = (C_MOVESTO.DTPOSIESTQ - 1)
            AND WI_CC = C_MOVESTO.CDFILIAL;

         /* Retorna o sequencial para a tabela */
         BEGIN
            SELECT WI_IDCUSTO.NEXTVAL
              INTO V_NOVOCODIGO
              FROM DUAL;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_NOVOCODIGO := 1;
         END;

         IF V_NUMI = 0 THEN
            /* Insere dados referente a posio de estoque */
            INSERT INTO USR_ZWI
               (WI_IDCUSTO, WI_EMPRESA, WI_FILIAL, WI_COD,
                WI_DATA, WI_CC, WI_CUSTO,
                WI_TPEDI, WI_DTGRV, WI_HRGRV)
            VALUES
               (V_NOVOCODIGO, SUBSTR(V_FILIAL,7,2), SUBSTR(V_FILIAL,9,2), SUBSTR(C_MOVESTO.CDARVPROD,1,15),
                C_MOVESTO.DTPOSIESTQ - 1, C_MOVESTO.CDFILIAL, ROUND(C_MOVESTO.VRESTOQDIA,5),
                '1', V_DTGRV, V_HRGRV);
         ELSE
            /* Insere dados referente a posio de estoque */
            INSERT INTO USR_ZWI
               (WI_IDCUSTO, WI_EMPRESA, WI_FILIAL, WI_COD,
                WI_DATA, WI_CC, WI_CUSTO,
                WI_TPEDI, WI_DTGRV, WI_HRGRV)
            VALUES
               (V_NOVOCODIGO, SUBSTR(V_FILIAL,7,2), SUBSTR(V_FILIAL,9,2), SUBSTR(C_MOVESTO.CDARVPROD,1,15),
                C_MOVESTO.DTPOSIESTQ - 1, C_MOVESTO.CDFILIAL, ROUND(C_MOVESTO.VRESTOQDIA,5),
                '2', V_DTGRV, V_HRGRV);

            /* Retorna o sequencial para a tabela */
            BEGIN
               SELECT WI_IDCUSTO.NEXTVAL
                 INTO V_NOVOCODIGO
                 FROM DUAL;
            EXCEPTION
               WHEN NO_DATA_FOUND THEN
                  V_NOVOCODIGO := 1;
            END;

            /* Insere dados referente a posio de estoque */
            INSERT INTO USR_ZWI
               (WI_IDCUSTO, WI_EMPRESA, WI_FILIAL, WI_COD,
                WI_DATA, WI_CC, WI_CUSTO,
                WI_TPEDI, WI_DTGRV, WI_HRGRV)
            VALUES
               (V_NOVOCODIGO, SUBSTR(V_FILIAL,7,2), SUBSTR(V_FILIAL,9,2), SUBSTR(C_MOVESTO.CDARVPROD,1,15),
                C_MOVESTO.DTPOSIESTQ - 1, C_MOVESTO.CDFILIAL, ROUND(C_MOVESTO.VRESTOQDIA,5),
                '1', V_DTGRV, V_HRGRV);
         END IF;
      END IF;
   END LOOP;
   COMMIT;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('USR_CUSTOSPROD','5.09.000'); END;
/

