/* Sistemas Integrados TECNISA
   Planejamento Alimentao Industrial

Nome: VALIDA_CARDAPIO_FECDIA.SQL

Descrio:
Retorna a quantidade do Produto em uma determinada data.

@C:\Web_605\Sql\End_Conv\Oracle\0313_PLASTPO_VALIDA_CARDAPIO_FECDIA.SQL

Criao:
18/12/2017 - Cristiane Faria

P_CDSERVSEMEFET -> RETORNA OS SERVICOS QUE ESTAO SEM EFETIVOS INFORMADOS
P_CDSERVNEVOL -> RETORNA OS SERVICOS QUE A RETIRADA NAO EVOLUIU O ESTOQUE
P_CDSERVNRETIRA -> RETORNA OS SERVIOS QUE NO TIVERAM RETIRADA
P_CDSERVDIFEFET -> RETORNA OS SERVICOS QUE OS COMENSAIS PLANEJADOS DIFEREM DO EFETIVO

Manutenes:
__/__/____ - _______ ___________
*/

IF EXISTS (SELECT *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'VALIDA_CARDAPIO_FECDIA' AND
                 TYPE = 'P' AND
                 U.UID = O.UID  AND
                 U.NAME = USER)
DROP PROCEDURE VALIDA_CARDAPIO_FECDIA
GO

CREATE PROCEDURE VALIDA_CARDAPIO_FECDIA(
   @P_CDFILIAL       VARCHAR(04),
   @P_DATAPROC       DATETIME,
   @P_CDSERVDIFEFET  TEXT OUTPUT,
   @P_SEMEFETIVOS    VARCHAR(01) OUTPUT,
   @P_SEMRETIRADA    VARCHAR(01) OUTPUT,
   @P_NAOEVOLESTOQ   VARCHAR(01) OUTPUT,
   @P_SERVSEMRETI    VARCHAR(01) OUTPUT)
AS

   DECLARE @V_CDSERVDIFEFET     VARCHAR(2000);
   DECLARE @V_IDEFETCARDIA      VARCHAR(01);
   DECLARE @V_IDBLOFECHMES      VARCHAR(01);
   DECLARE @V_FATUSERV          VARCHAR(1);
   DECLARE @V_TEMRETIRADA       VARCHAR(1);
   DECLARE @V_IDBLOFERTNEV      VARCHAR(01);
   DECLARE @V_SEMEFETIVOS       VARCHAR(04);
   DECLARE @V_IDBLOQEFEPDIFEFEF VARCHAR(01);
   DECLARE @V_IDCONSCOMFAT      VARCHAR(01);
   DECLARE @V_QTCOMEFETCLI      DOUBLE PRECISION;
   DECLARE @V_IDEVOLESTOQ       VARCHAR(02);
   DECLARE @V_TOTALEFET         DOUBLE PRECISION;

/* VARIVEIS DO CURSOR PLANEJADO */
   DECLARE @PLANEJADO_NRCARDAPIO     VARCHAR(10);
   DECLARE @PLANEJADO_CDSERVFILI     VARCHAR(05);
   DECLARE @PLANEJADO_QTCLIEFETCAR   DOUBLE PRECISION;
   DECLARE @PLANEJADO_IDSERVATIV     VARCHAR(01);

/* VARIVEIS DO CURSOR NAOPLANEJADO */
   DECLARE @NAOPLANEJADO_NRCARDAPIO     VARCHAR(10);
   DECLARE @NAOPLANEJADO_CDSERVFILI     VARCHAR(05);
   DECLARE @NAOPLANEJADO_QTCLIEFETCAR   DOUBLE PRECISION;

/* VARIVEIS DO CURSOR EFETIVOS */
   DECLARE @EFETIVOS_CDSERVFILI        VARCHAR(05);
   DECLARE @EFETIVOS_CDSERVICFATURAM   VARCHAR(05);

/* VARIVEIS DO CURSOR EFETIVOSNPLAN */
   DECLARE @EFETIVOSNPLAN_CDSERVFILI        VARCHAR(05);
   DECLARE @EFETIVOSNPLAN_CDSERVICFATURAM   VARCHAR(05);

BEGIN

   SET @P_CDSERVDIFEFET = '';
   SET @P_SEMEFETIVOS   = 'N';
   SET @P_SEMRETIRADA   = '';
   SET @P_NAOEVOLESTOQ  = '';
   SET @P_SERVSEMRETI   = '';

   SET @V_CDSERVDIFEFET  = '';

   SET @V_IDCONSCOMFAT   = 'N';
   SET @V_QTCOMEFETCLI   = 0;
   SET @V_IDEVOLESTOQ    = NULL;
   SET @V_TOTALEFET      = 0;
   SET @V_SEMEFETIVOS    = 'N';
   SET @V_IDEFETCARDIA   = 'N';
   SET @V_IDBLOFECHMES   = 'N';
   SET @V_IDBLOFERTNEV   = 'N';
   SET @V_IDBLOQEFEPDIFEFEF = 'N';

   SELECT @V_IDEFETCARDIA = ISNULL(IDEFETCARDIA,'N')
     FROM PARAMPLANEJA
   WHERE (CDFILIAL = @P_CDFILIAL);

   /*VERIFICA O PARAMETRO -> No  possvel realizar o fechamento do dia sem antes efetuar o lanamento de retirada.*/
   SELECT @V_IDBLOFECHMES = ISNULL(IDBLOFECHMES,'N'),
          @V_IDBLOFERTNEV = ISNULL(IDBLOFERTNEV,'N'),
          @V_IDBLOQEFEPDIFEFEF = ISNULL(IDBLOQEFEPDIFEFEF,'N')
     FROM PARAMFILIAL P, FILIAL F
    WHERE (P.CDFILIAL = @P_CDFILIAL)  AND
          (P.CDFILIAL = F.CDFILIAL);

   /*Verifica Comensais Efetivos no Fechamento do Dia*/
   IF ISNULL(@V_IDEFETCARDIA,'N') = 'S' BEGIN
      /*se o select retornar dado, da msg para o usuario:*/
      /*Operao bloqueada. No  permitido fazer o fechamento do dia sem que os comensais efetivos sejam lanados para todos os servios da filial.*/
      SELECT @V_SEMEFETIVOS = MAX(CA.CDFILIAL)
      FROM
         SERVICO SE,
         CARDADIA CA
      WHERE
         (CA.CDFILIAL   = @P_CDFILIAL)   AND
         (CA.DTCARDAPIO = @P_DATAPROC)   AND
         (SE.CDFILIAL   = CA.CDFILIAL)   AND
         (SE.CDSERVFILI = CA.CDSERVFILI) AND
         (SE.IDSERVPADR = 'N')           AND
         (QTCOMEFETCAR IS NULL)          AND
          EXISTS (SELECT NRCARDAPIO
                  FROM RETIRADA RE
                   WHERE (RE.CDFILIAL   = CA.CDFILIAL) AND
                         (RE.NRCARDAPIO = CA.NRCARDAPIO));
   END;

   /* SE FOR LOCALIZADA RETIRADA SEM EFETIVOS INFORMADOS NO CARDPIO EMITE MENSAGEM DE ERRO PARA O USUARIO*/
   IF ISNULL(@V_SEMEFETIVOS,'N') <> 'N' BEGIN
      SET @P_SEMEFETIVOS = 'S';
      RETURN;
   END
   ELSE BEGIN
      /*SE EXISTE RETIRADA PARA O DIA OU NO BLOQUEIA FECHAMENTO DO DIA SEM RETIRADA*/
      IF (ISNULL(@V_IDBLOFECHMES,'N') = 'S') BEGIN

         SET @V_TEMRETIRADA = 'N';

         /*se o select no retornar dado, da msg para o usuario:*/
         /*Operao bloqueada! No  possvel realizar o fechamento do dia sem antes efetuar o lanamento de retirada.*/
         SELECT @V_TEMRETIRADA = MAX('S')
           FROM RETIRADA
          WHERE (DTRETIRADA = @P_DATAPROC)  AND
                (CDFILIAL = @P_CDFILIAL);

         /*Operao bloqueada! No  possvel realizar o fechamento do dia sem antes efetuar o lanamento de retirada.*/
         IF ISNULL(@V_TEMRETIRADA,'N') = 'N' BEGIN
            SET @P_SEMRETIRADA = 'S';
            RETURN;
         END;

         /*VERIFICA O CARDAPIO PLANEJADO*/
         DECLARE PLANEJADO CURSOR FOR
            SELECT C.NRCARDAPIO, C.CDSERVFILI, ISNULL(C.QTCLIEFETCAR,0) AS QTCLIEFETCAR, ISNULL(IDSERVATIV,'N') AS IDSERVATIV
              FROM CARDADIA C, SERVICO S
             WHERE C.CDFILIAL   = @P_CDFILIAL
               AND C.DTCARDAPIO = @P_DATAPROC
               AND C.CDFILIAL   = S.CDFILIAL
               AND C.CDSERVFILI = S.CDSERVFILI
               AND S.IDTIPOSERV = 'N'
               AND EXISTS (SELECT CDFILIAL, NRCARDAPIO
                             FROM COMPCARD
                            WHERE COMPCARD.CDFILIAL = C.CDFILIAL
                              AND COMPCARD.NRCARDAPIO = C.NRCARDAPIO)
                              AND ((ISNULL(C.QTCLIEFETCAR,0) > 0) OR (EXISTS(SELECT CDFILIAL FROM RETIRADA WHERE RETIRADA.CDFILIAL = C.CDFILIAL
                                                                                                             AND RETIRADA.NRCARDAPIO = C.NRCARDAPIO)))
                              ORDER BY C.CDSERVFILI;
         OPEN PLANEJADO;
         FETCH NEXT FROM PLANEJADO INTO @PLANEJADO_NRCARDAPIO, @PLANEJADO_CDSERVFILI, @PLANEJADO_QTCLIEFETCAR, @PLANEJADO_IDSERVATIV;
         WHILE (@@FETCH_STATUS = 0) BEGIN
            /*VERIFICA SE A RETIRADA FOI REALIZADA PARA TODOS OS SERVIOS*/
            SELECT @V_IDEVOLESTOQ = MIN(ISNULL(C.IDEVOLESTOQ,'N')) /*MIN PQ SE TIVER ALGUM REGISTRO COM N, RETORNA 'N', SE FOSSE MAX RETORNARIA 'S'*/
              FROM RETIRADA R, ITEMRETI A, ITLANCTOEST C
             WHERE (R.CDFILIAL     = @P_CDFILIAL)
               AND (C.CDFILIMOVI   = @P_CDFILIAL)
               AND (C.DTLANCMOVI   = @P_DATAPROC)
               AND (R.NRCARDAPIO   = @PLANEJADO_NRCARDAPIO)
               AND (R.CDFILIAL     = A.CDFILIAL)
               AND (R.NRRETIRADA   = A.NRRETIRADA)
               AND (R.NRCARDAPIO   = A.NRCARDAPIO)
               AND (A.CDFIITLANEST = C.CDFILIAL  )
               AND (A.NRLANCESTQ   = C.NRLANCESTQ)
               AND (A.NRSEQUITEM   = C.NRSEQUITEM);

            IF @V_IDEVOLESTOQ IS NULL BEGIN
               SET @V_IDEVOLESTOQ = 'NR';  /*NAO LOCALIZOU A RETIRADA*/
            END;

            /*SE O ESTOQUE NO FOI EVOLUIDO NA RETIRADA PARA ALGUM ITEM*/
            IF (ISNULL(@V_IDEVOLESTOQ,'NR') = 'N') AND (ISNULL(@V_IDBLOFERTNEV,'N') = 'S') BEGIN
               SET @P_NAOEVOLESTOQ = 'S';
               RETURN;
            END
            ELSE BEGIN
               /* SE A RETIRADA NAO FOI LOCALIZADA PARA O SERVICO E O SERVICO ESTA HABILITADO EM PREVISES, REQUISIES E RETIRADAS E */
               /* E O PARAMETRO ESTA PARA BLOQUEAR DIA SEM RETIRADA */
               IF (ISNULL(@V_IDEVOLESTOQ,'NR') = 'NR') AND (@PLANEJADO_IDSERVATIV = 'S') AND (ISNULL(@V_IDBLOFECHMES,'N') = 'S') BEGIN
                  SET @P_SERVSEMRETI = 'S';
                  RETURN;
               END;
            END;

            /*CASO ESTEJA PARAMETRIZADO PARA BLOQUEAR PLANEJADO DIFERENTE DO EFETIVO*/
            IF ISNULL(@V_IDBLOQEFEPDIFEFEF,'N') = 'S' BEGIN

                /*SELECT PARA PEGAR O PARAMETRO DO SERVICO PRINCIPAL E NAO DOS SERVICOS RELACIONADOS*/
                /*Consistencias de Comensais do Faturamento x Comensais do Planejamento*/
               SELECT @V_IDCONSCOMFAT = ISNULL(IDCONSCOMFAT,'N')
                 FROM SERVICO
                WHERE CDFILIAL = @P_CDFILIAL
                  AND CDSERVFILI = @PLANEJADO_CDSERVFILI;

               /*VERIFICA SE O SERVICO  FATURADO PARA A FILIAL*/
               SELECT @V_FATUSERV = ISNULL(IDFATUSERV,'S')
                 FROM SERVICO
                WHERE CDFILIAL = @P_CDFILIAL
                  AND CDSERVFILI = @PLANEJADO_CDSERVFILI;

               /*VERIFICA SE TEM EFETIVOS PARA O SERVIO OU PARA O SERVICO DE FATURAMENTO*/
               DECLARE EFETIVOS CURSOR FOR
               SELECT CARDADIA.CDSERVFILI, ISNULL(SERVIFAT.CDSERVICFATURAM, CARDADIA.CDSERVFILI) AS CDSERVICFATURAM
                 FROM CARDADIA LEFT JOIN SERVIFAT ON (CARDADIA.CDFILIAL   = SERVIFAT.CDFILIAL) AND
                                                     (CARDADIA.CDSERVFILI = SERVIFAT.CDSERVFILI),
                      SERVICO
                 WHERE CARDADIA.CDFILIAL   = @P_CDFILIAL
                   AND CARDADIA.NRCARDAPIO = @PLANEJADO_NRCARDAPIO
                   AND CARDADIA.CDFILIAL   = SERVICO.CDFILIAL
                   AND SERVICO.CDSERVFILI  = ISNULL(SERVIFAT.CDSERVICFATURAM, CARDADIA.CDSERVFILI)
                   ORDER BY CARDADIA.CDSERVFILI, ISNULL(SERVIFAT.CDSERVICFATURAM, CARDADIA.CDSERVFILI);
               OPEN EFETIVOS;
               FETCH NEXT FROM EFETIVOS INTO @EFETIVOS_CDSERVFILI, @EFETIVOS_CDSERVICFATURAM;
               WHILE (@@FETCH_STATUS = 0) BEGIN
                  /*VERIFICA SE TEM EFETIVO PARA O SERVICO*/
                  SELECT @V_QTCOMEFETCLI = ISNULL(SUM(ISNULL(E.QTCOMEFETCLI, 0) + ISNULL(E.QTVENDAEFETCLI, 0)),0)
                  FROM SERVCLIE S, EFETCLIE E
                  WHERE S.CDFILIAL      = @P_CDFILIAL
                    AND S.CDSERVFILI    = @EFETIVOS_CDSERVICFATURAM
                    AND S.CDFILIAL      = E.CDFILIAL
                    AND S.CDSERVFILI    = E.CDSERVFILI
                    AND S.CDCLIENTE     = E.CDCLIENTE
                    AND E.DTEFETCLIE    = @P_DATAPROC
                    AND E.CDSERVPLAN    = @EFETIVOS_CDSERVFILI;

                  SET @V_TOTALEFET = @V_TOTALEFET + @V_QTCOMEFETCLI;
                  FETCH NEXT FROM EFETIVOS INTO @EFETIVOS_CDSERVFILI, @EFETIVOS_CDSERVICFATURAM;
               END;
               CLOSE EFETIVOS;
               DEALLOCATE EFETIVOS;

               /*Efetivos planejados diferem dos efetivos faturados*/
               IF (@V_TOTALEFET <> @PLANEJADO_QTCLIEFETCAR) AND (@V_FATUSERV = 'S') BEGIN
                  SET @V_CDSERVDIFEFET = @V_CDSERVDIFEFET + '_' + @PLANEJADO_CDSERVFILI;
               END;
            END;

            SET @V_TOTALEFET    = 0;
            SET @V_QTCOMEFETCLI = 0;
            SET @V_IDEVOLESTOQ  = 'S';
            FETCH NEXT FROM PLANEJADO INTO @PLANEJADO_NRCARDAPIO, @PLANEJADO_CDSERVFILI, @PLANEJADO_QTCLIEFETCAR, @PLANEJADO_IDSERVATIV;
         END;
         CLOSE PLANEJADO;
         DEALLOCATE PLANEJADO;

         /*   CARDAPIO NAO PLANEJADO    */
         SET @V_QTCOMEFETCLI   = 0;
         SET @V_IDEVOLESTOQ    = 'S';
         SET @V_TOTALEFET      = 0;

         /*VERIFICA O CARDAPIO NO PLANEJADO, DESCONSIDERANDO O SERVICO PARA RETIRADA AUTOMATICA, POIS CASO ESTE ESTEJA PARAMETRIZADO, O FECHAMENTO DO DIA NAO SERA BLOQUEADO*/
         DECLARE NAOPLANEJADO CURSOR FOR
           SELECT C.NRCARDAPIO, C.CDSERVFILI, ISNULL(C.QTCLIEFETCAR,0) AS QTCLIEFETCAR
              FROM CARDADIA C, SERVICO S, PARAMPLANEJA P
             WHERE C.CDFILIAL   = @P_CDFILIAL
               AND C.DTCARDAPIO = @P_DATAPROC
               AND C.CDFILIAL   = S.CDFILIAL
               AND C.CDSERVFILI = S.CDSERVFILI
               AND S.IDTIPOSERV = 'N'
               AND P.CDFILIAL = C.CDFILIAL
               AND C.CDSERVFILI <> P.CDSERVRETPME
               AND NOT EXISTS (SELECT CDFILIAL, NRCARDAPIO
                                 FROM COMPCARD
                                WHERE COMPCARD.CDFILIAL = C.CDFILIAL
                                  AND COMPCARD.NRCARDAPIO = C.NRCARDAPIO)
                                  AND ((ISNULL(C.QTCLIEFETCAR,0) > 0) OR (EXISTS(SELECT CDFILIAL
                                                                                 FROM RETIRADA
                                                                                 WHERE RETIRADA.CDFILIAL = C.CDFILIAL
                                                                                   AND RETIRADA.NRCARDAPIO = C.NRCARDAPIO)))

                              ORDER BY C.CDSERVFILI;
         OPEN NAOPLANEJADO;
         FETCH NEXT FROM NAOPLANEJADO INTO @NAOPLANEJADO_NRCARDAPIO, @NAOPLANEJADO_CDSERVFILI, @NAOPLANEJADO_QTCLIEFETCAR;
         WHILE (@@FETCH_STATUS = 0) BEGIN

            /*VERIFICA SE A RETIRADA FOI REALIZADA*/
            SELECT @V_IDEVOLESTOQ = MIN(ISNULL(C.IDEVOLESTOQ,'N')) /*MIN PQ SE TIVER ALGUM REGISTRO COM N, RETORNA 'N', SE FOSSE MAX RETORNARIA 'S'*/
              FROM RETIRADA R, ITEMRETI A, ITLANCTOEST C
             WHERE (R.CDFILIAL     = @P_CDFILIAL)
               AND (C.CDFILIMOVI   = @P_CDFILIAL)
               AND (C.DTLANCMOVI   = @P_DATAPROC)
               AND (R.NRCARDAPIO   = @NAOPLANEJADO_NRCARDAPIO)
               AND (R.CDFILIAL     = A.CDFILIAL)
               AND (R.NRRETIRADA   = A.NRRETIRADA)
               AND (R.NRCARDAPIO   = A.NRCARDAPIO)
               AND (A.CDFIITLANEST = C.CDFILIAL  )
               AND (A.NRLANCESTQ   = C.NRLANCESTQ)
               AND (A.NRSEQUITEM   = C.NRSEQUITEM);

            IF @V_IDEVOLESTOQ IS NULL BEGIN
               SET @V_IDEVOLESTOQ = 'NR';  /*NAO LOCALIZOU A RETIRADA*/
            END;

            /*VERIFICA SE O ESTOQUE FOI EVOLUIDO NA RETIRADA*/
            IF (ISNULL(@V_IDEVOLESTOQ,'NR') = 'N') AND (ISNULL(@V_IDBLOFERTNEV,'N') = 'S') BEGIN /*O ESTOQUE NAO FOI EVOLUIDO*/
                SET @P_NAOEVOLESTOQ = 'S';
                RETURN;
            END;

            /*INDICA QUE TEVE RETIRADA E QUE BLOQUEIA EFETIVO DIFERENTE DO PLANEJADO*/
            IF (ISNULL(@V_IDEVOLESTOQ,'NR') <> 'NR') AND (ISNULL(@V_IDBLOQEFEPDIFEFEF,'N') = 'S') BEGIN

               /*SELECT PARA PEGAR O PARAMETRO DO SERVICO PRINCIPAL E NAO DOS SERVICOS RELACIONADOS*/
               /*Consistencias de Comensais do Faturamento x Comensais do Planejamento*/
               SELECT @V_IDCONSCOMFAT = ISNULL(IDCONSCOMFAT,'N')
                 FROM SERVICO
                WHERE CDFILIAL = @P_CDFILIAL
                  AND CDSERVFILI = @NAOPLANEJADO_CDSERVFILI;

               /*VERIFICA SE O SERVICO  FATURADO PARA A FILIAL*/
               SELECT @V_FATUSERV = ISNULL(IDFATUSERV,'S')
                 FROM SERVICO
                WHERE CDFILIAL = @P_CDFILIAL
                  AND CDSERVFILI = @NAOPLANEJADO_CDSERVFILI;

               /*VERIFICA SE TEM EFETIVOS PARA O SERVIO OU PARA O SERVICO DE FATURAMENTO*/
               DECLARE EFETIVOSNPLAN CURSOR FOR
                  SELECT CARDADIA.CDSERVFILI, ISNULL(SERVIFAT.CDSERVICFATURAM, CARDADIA.CDSERVFILI) AS CDSERVICFATURAM
                    FROM CARDADIA LEFT JOIN SERVIFAT ON (CARDADIA.CDFILIAL   = SERVIFAT.CDFILIAL) AND
                                                        (CARDADIA.CDSERVFILI = SERVIFAT.CDSERVFILI),
                         SERVICO
                   WHERE CARDADIA.CDFILIAL   = @P_CDFILIAL
                     AND CARDADIA.NRCARDAPIO = @NAOPLANEJADO_NRCARDAPIO
                     AND CARDADIA.CDFILIAL   = SERVICO.CDFILIAL
                     AND SERVICO.CDSERVFILI  = ISNULL(SERVIFAT.CDSERVICFATURAM, CARDADIA.CDSERVFILI)
                  ORDER BY CARDADIA.CDSERVFILI, ISNULL(SERVIFAT.CDSERVICFATURAM, CARDADIA.CDSERVFILI);
               OPEN EFETIVOSNPLAN;
               FETCH NEXT FROM EFETIVOSNPLAN INTO @EFETIVOSNPLAN_CDSERVFILI, @EFETIVOSNPLAN_CDSERVICFATURAM;
               WHILE (@@FETCH_STATUS = 0) BEGIN

                  /*VERIFICA SE TEM EFETIVO PARA O SERVICO*/
                  SELECT @V_QTCOMEFETCLI = ISNULL(SUM(ISNULL(E.QTCOMEFETCLI, 0) + ISNULL(E.QTVENDAEFETCLI, 0)),0)
                    FROM SERVCLIE S, EFETCLIE E
                   WHERE S.CDFILIAL      = @P_CDFILIAL
                     AND S.CDSERVFILI    = @EFETIVOSNPLAN_CDSERVICFATURAM
                     AND S.CDFILIAL      = E.CDFILIAL
                     AND S.CDSERVFILI    = E.CDSERVFILI
                     AND S.CDCLIENTE     = E.CDCLIENTE
                     AND E.DTEFETCLIE    = @P_DATAPROC
                     AND E.CDSERVPLAN    = @EFETIVOSNPLAN_CDSERVFILI;

                  SET @V_TOTALEFET = @V_TOTALEFET + @V_QTCOMEFETCLI;
                  FETCH NEXT FROM EFETIVOSNPLAN INTO @EFETIVOSNPLAN_CDSERVFILI, @EFETIVOSNPLAN_CDSERVICFATURAM;
               END;
               CLOSE EFETIVOSNPLAN;
               DEALLOCATE EFETIVOSNPLAN;

               /*Efetivos planejados diferem dos efetivos faturados*/
               IF (@V_TOTALEFET <> @NAOPLANEJADO_QTCLIEFETCAR) AND (@V_FATUSERV = 'S') BEGIN
                  SET @V_CDSERVDIFEFET = @V_CDSERVDIFEFET + '_' + @NAOPLANEJADO_CDSERVFILI;
               END;
            END;

            SET @V_TOTALEFET    = 0;
            SET @V_QTCOMEFETCLI = 0;
            SET @V_IDEVOLESTOQ  = 'S';
            FETCH NEXT FROM NAOPLANEJADO INTO @NAOPLANEJADO_NRCARDAPIO, @NAOPLANEJADO_CDSERVFILI, @NAOPLANEJADO_QTCLIEFETCAR;
         END;
         CLOSE NAOPLANEJADO;
         DEALLOCATE NAOPLANEJADO;
      END;
   END;

   SET @P_CDSERVDIFEFET  = @V_CDSERVDIFEFET;
   RETURN;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'VALIDA_CARDAPIO_FECDIA','6.19.000'; 
GO
