function crm00040001_Tipo_Revenda_Controller(General, CRM_Utilities, templateManager) {
    
    /**
     * Acrescenta os parâmetros na widget para 
     * gerar um novo código e salva o novo tipo de 
     * revenda
     * 
     * @param {object} widget widget com as informações
     * para realizar o 'save'
    */
    this.saveTypeOfResale = function(widget){
        
        var currentRow = widget.currentRow;
        
        if(currentRow.__is_new === true){
            
            var paramsNewCode = {
                    __is_new_code: true,
                    __new_code_pk: "NRTIPOREVENDA",
                    __table_pk: "NRTIPOREVENDA",
                    __cast_number: true
                };
                
            widget.paramsNewCode = paramsNewCode;
        
        }
        
        General.widgetSave(widget).then(function(){
            widget.reload();
        });
        
    };
    
     /**
     * Save:
     * Atribui widget ativa os parâmetros
     * para gerar um novo código.
     * 
     * Seta o tipo de revenda na currentRow. 
     * 
     * Remove a máscara do valor da comissão e salva a 
     * nova comissão.
     * 
     * Edit: 
     * Salva a edição da comissão.
     * 
     * @param {object} widget widget com as informações
     * para o 'save'
    */
    this.editValuesWidgetAndSaveCommission = function(widget){
        
        var currentRow = widget.currentRow;
        
        if(currentRow.__is_new === true){
            
            var paramsNewCode = {
                    __is_new_code: true,
                    __new_code_pk: "NRCOMISSAOTPREVENDA",
                    __table_pk: "NRCOMISSAOTPREVENDA",
                    __cast_number: true
                };
                
            widget.paramsNewCode = paramsNewCode;
            currentRow.NRTIPOREVENDA = widget.parent.parent.currentRow.NRTIPOREVENDA;
            currentRow.VRCOMISSAO = currentRow.VRCOMISSAO.replace(/[^0-9]/g, "");
        
        }
        
        General.widgetSave(widget).then(function(){
            widget.reload();
        });
        
    };
    
    /**
     * Função que busca o index do objeto dentro do 
     * dataSourceFilter da widget passada como parâmetro
     * e seta o número da revenda relacionada.
    */
    this.setFilterCommissionWidget = function(){
        
        var widget = templateManager.container.getWidget('COMISSAO');
        
        var indexFilterObject = CRM_Utilities.getFilterPosition(widget.dataSourceFilter, "NRTIPOREVENDA");
        
        widget.dataSourceFilter[indexFilterObject].value = widget.parent.parent.currentRow.NRTIPOREVENDA;
        
    };
    
    /**
     * Função para setar os valores iniciais
     * da widget que recebeu o evento newRow .
     * 
     * @param {object} widget widget onde será setada
     * os valores na currentRow.
    */
    this.setCurrentRowWidget = function(widget){
        
        var currentRow = widget.currentRow;
            
        currentRow.CDPRECBASESERV = "";
        currentRow.CDMODPGTO = "";
        
    };
    
    /**
     * Função para pegar os serviços já cadastrados
     * presente no dataSouce,caso não tenha, retorna
     * um array com o item '-1'.
     * 
     * @param {object} widget widget de comissões para
     * localizar os serviços usados.
     * 
     * @return {array} usedServicesArray array com os
     * serviços usasdos.
    */
    this.getUsedServiceArray = function(widget){
        
        var usedServicesArray = [-1];
        var dataSourceValues = widget.dataSource.data;
        
        dataSourceValues.map(function(values){
            if(values.CDSERVORCA){
                usedServicesArray.push(values.CDSERVORCA);
            }
        });
        
        return usedServicesArray;
        
    };
    
    /**
     * Função para setar o array de serviços ja 
     * cadastrados no valor do filtro da field
     * de serviço.
     * 
     * @param {object} widget widget de comissão.
    */
    this.setServiceFieldFilter = function(widget){
        
        var fieldNMSERVOCA = widget.getField('NMSERVORCA');
        
        var serviceFilter = fieldNMSERVOCA.dataSourceFilter;
        var usedServicesArray = this.getUsedServiceArray(widget);
        
        var indexCDSERVORCAinFilter = CRM_Utilities.getFilterPosition(serviceFilter, "CDSERVORCA");
        serviceFilter[indexCDSERVORCAinFilter].value = usedServicesArray;
        
        fieldNMSERVOCA.reload();
        
    };

}

Configuration(function(ContextRegister) {
    ContextRegister.register('crm00040001_Tipo_Revenda_Controller', crm00040001_Tipo_Revenda_Controller);
});